@@ -94,6 +94,9 @@ void EvernoteImportDialog::initNoteCount(const QString &data) {
 
     ui->progressBar->setMaximum(count);
     ui->progressBar->show();
+#else
+    qWarning() << Q_FUNC_INFO << "not implemented for qt6";
+    Q_UNUSED(data)
 #endif
 }
 
@@ -237,16 +240,17 @@ QString EvernoteImportDialog::importImages(const Note &note, QString content,
         // get the base64 encoded image
         MediaFileData mediaFileData = mediaFileDataHash[objectId];
 
-        // get the markdown code for the image file data entry
+        // get the Markdown code for the image file data entry
         QString markdownCode = getMarkdownForMediaFileData(note, mediaFileData);
 
         if (!markdownCode.isEmpty()) {
-            // replace image tag with markdown code
-            content.replace(imageTag, markdownCode);
+            // replace image tag with Markdown code (and a leading newline, since
+            // Evernote doesn't support inline images, and we like to add a spacer)
+            content.replace(imageTag, QStringLiteral("\n") + markdownCode);
         }
     }
 
-    // get the image markdown code for missing images
+    // get the image Markdown code for missing images
     QHashIterator<QString, MediaFileData> hashIterator(mediaFileDataHash);
     while (hashIterator.hasNext()) {
         hashIterator.next();
@@ -257,7 +261,7 @@ QString EvernoteImportDialog::importImages(const Note &note, QString content,
 
         MediaFileData mediaFileData = hashIterator.value();
 
-        // get the markdown code for the image file data entry
+        // get the Markdown code for the image file data entry
         QString markdownCode = getMarkdownForMediaFileData(note, mediaFileData);
 
         content += QStringLiteral("\n") + markdownCode;
@@ -391,17 +395,17 @@ QString EvernoteImportDialog::importAttachments(const Note &note,
         // get the base64 encoded file
         MediaFileData mediaFileData = mediaFileDataHash[objectId];
 
-        // get the markdown code for the file data entry
+        // get the Markdown code for the file data entry
         QString markdownCode =
             getMarkdownForAttachmentFileData(note, mediaFileData);
 
         if (!markdownCode.isEmpty()) {
-            // replace media tag with markdown code
+            // replace media tag with Markdown code
             content.replace(mediaTag, markdownCode);
         }
     }
 
-    // get the file markdown code for missing attachments
+    // get the file's Markdown code for missing attachments
     QHashIterator<QString, MediaFileData> hashIterator(mediaFileDataHash);
     while (hashIterator.hasNext()) {
         hashIterator.next();
@@ -412,7 +416,7 @@ QString EvernoteImportDialog::importAttachments(const Note &note,
 
         MediaFileData mediaFileData = hashIterator.value();
 
-        // get the markdown code for the file data entry
+        // get the Markdown code for the file data entry
         QString markdownCode =
             getMarkdownForAttachmentFileData(note, mediaFileData);
 
@@ -456,7 +460,8 @@ void EvernoteImportDialog::importNotes(const QString &data) {
             // content seems to be html encoded
             query.evaluateTo(&content);
 
-            Utils::Misc::transformEvernoteImportText(content);
+            // unescape content
+            Utils::Misc::unescapeEvernoteImportText(content);
 
             if (ui->imageImportCheckBox->isChecked()) {
                 // import images
@@ -468,7 +473,9 @@ void EvernoteImportDialog::importNotes(const QString &data) {
                 content = importAttachments(note, std::move(content), query);
             }
 
-            Utils::Misc::cleanupEvernoteImportText(content);
+            // we need to do that after images and attachments are imported,
+            // otherwise they will not be detected in-line
+            Utils::Misc::transformEvernoteImportText(content, true);
 
 #ifdef Q_OS_WIN32
             // removing or replacing some characters that are asking for
@@ -550,7 +557,7 @@ void EvernoteImportDialog::tagNote(QXmlQuery &query, Note &note) {
 }
 
 /**
- * Generates the metadata markdown table for a note
+ * Generates the metadata Markdown table for a note
  */
 QString EvernoteImportDialog::generateMetaDataMarkdown(QXmlQuery query) {
     QString resultText;
@@ -757,7 +764,7 @@ void EvernoteImportDialog::on_importButton_clicked() {
 }
 
 /**
- * Returns the markdown code for an image file data entry
+ * Returns the Markdown code for an image file data entry
  *
  * @param mediaFileData
  * @return
@@ -771,7 +778,7 @@ QString EvernoteImportDialog::getMarkdownForMediaFileData(
 }
 
 /**
- * Returns the markdown code for an attachment file data entry
+ * Returns the Markdown code for an attachment file data entry
  *
  * @param mediaFileData
  * @return
@@ -795,7 +802,7 @@ QString EvernoteImportDialog::getMarkdownForAttachmentFileData(
     tempFile->write(QByteArray::fromBase64(data.toLatin1()));
 
     // store the temporary file in the media folder and return the
-    // markdown code
+    // Markdown code
     QString markdownCode = note.getInsertAttachmentMarkdown(tempFile, fileName);
 
     return markdownCode;
