@@ -160,6 +160,10 @@ bool mainStartupMisc(const QStringList &arguments) {
     Utils::Gui::doWindowsDarkModeCheck();
 #endif
 
+#ifdef Q_OS_LINUX
+    Utils::Gui::doLinuxDarkModeCheck();
+#endif
+
     bool systemIconTheme =
         settings.value(QStringLiteral("systemIconTheme")).toBool();
 
@@ -634,7 +638,7 @@ int main(int argc, char *argv[]) {
             w.activateWindow();
 
             // in case the window was minimized show it normal again
-            // (it didn't came up when it was minimized on KDE)
+            // (it didn't come up when it was minimized on KDE)
             if (w.isMinimized()) {
                 w.showNormal();
             }
