@@ -222,6 +222,10 @@ class MainWindow : public QMainWindow {
 
     void refreshNotePreview();
 
+    Q_INVOKABLE bool removeNoteTab(int index) const;
+
+    Q_INVOKABLE bool jumpToTag(int tagId);
+
    protected:
     void changeEvent(QEvent *event) override;
 
@@ -238,13 +242,17 @@ class MainWindow : public QMainWindow {
 
     void storeUpdatedNotesToDisk();
 
-    void changeNoteFolder(const int noteFolderId,
+    bool changeNoteFolder(const int noteFolderId,
                           const bool forceChange = false);
 
     void allowNoteEditing();
 
     void disallowNoteEditing();
 
+    void openSelectedNotesInTab();
+
+    void openNoteInTab(const Note& note);
+
     void openCurrentNoteInTab();
 
     Q_INVOKABLE void focusNoteTextEdit();
@@ -1095,7 +1103,6 @@ private:
     void updateCurrentTabData(const Note &note) const;
     bool jumpToTab(const Note &note) const;
     void closeOrphanedTabs() const;
-    void removeNoteTab(int index) const;
     void automaticScriptUpdateCheck();
     void updateJumpToActionsAvailability();
     int getNoteTabIndex(int noteId) const;
