@@ -4,34 +4,32 @@
 #define PIWIK_TRACKER_DEBUG 1
 
 #include <QObject>
-#include <libraries/piwiktracker/piwiktracker.h>
 
-class MetricsService : public QObject
-{
+class PiwikTracker;
+
+class MetricsService : public QObject {
     Q_OBJECT
 
-public:
+   public:
     explicit MetricsService(QObject *parent = 0);
     void sendVisitIfEnabled(const QString &path = QString(),
                             const QString &actionName = QString());
     void sendVisit(const QString &path = QString(),
                    const QString &actionName = QString());
-    void sendEventIfEnabled(
-            const QString path,
-            const QString eventCategory,
-            const QString eventAction,
-            const QString eventName = "",
-            int eventValue = 0);
+    void sendEventIfEnabled(const QString &path, const QString &eventCategory,
+                            const QString &eventAction,
+                            const QString &eventName = QString(),
+                            int eventValue = 0);
     void sendHeartbeat();
     static MetricsService *instance();
-    static MetricsService *createInstance(QObject *parent = 0);
+    static MetricsService *createInstance(QObject *parent = nullptr);
     void sendLocaleEvent();
 
-private:
-    PiwikTracker * _piwikTracker;
+   private:
+    PiwikTracker *_piwikTracker;
     bool _firstHeartbeat;
 
-signals:
+   signals:
 
-public slots:
+   public slots:
 };
