@@ -71,10 +71,10 @@ OwnCloudService::OwnCloudService(int cloudConnectionId, QObject *parent)
                      this, SLOT(slotReplyFinished(QNetworkReply *)));
 
     readSettings(cloudConnectionId);
-    settingsDialog = Q_NULLPTR;
-    todoDialog = Q_NULLPTR;
-    mainWindow = Q_NULLPTR;
-    shareDialog = Q_NULLPTR;
+    settingsDialog = nullptr;
+    todoDialog = nullptr;
+    mainWindow = nullptr;
+    shareDialog = nullptr;
 }
 
 void OwnCloudService::resetNetworkManagerCookieJar() {
@@ -239,7 +239,7 @@ void OwnCloudService::slotAuthenticationRequired(
     qWarning() << "Username and/or password incorrect";
 
 #ifndef INTEGRATION_TESTS
-    if (settingsDialog != Q_NULLPTR) {
+    if (settingsDialog != nullptr) {
         settingsDialog->setOKLabelData(3, tr("incorrect"),
                                        SettingsDialog::Failure);
         settingsDialog->setOKLabelData(4, tr("not connected"),
@@ -348,13 +348,9 @@ void OwnCloudService::slotReplyFinished(QNetworkReply *reply) {
             QList<CalDAVCalendarData> calendarDataList =
                 parseCalendarData(data);
 
-            //#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
             //            qInfo() << "calendarDataList: " << calendarDataList;
-            //#else
-            //            qDebug() << "calendarDataList: " << calendarDataList;
-            //#endif
 
-            if (settingsDialog != Q_NULLPTR) {
+            if (settingsDialog != nullptr) {
                 settingsDialog->refreshTodoCalendarList(calendarDataList);
             }
         } else if (!todoCalendarServerUrlPath.isEmpty() &&
@@ -372,7 +368,7 @@ void OwnCloudService::slotReplyFinished(QNetworkReply *reply) {
                     data = QString();
                 }
 
-                if (todoDialog != Q_NULLPTR) {
+                if (todoDialog != nullptr) {
                     // this will mostly happen after the PUT request to update
                     // or create a task item
                     if (data.isEmpty()) {
@@ -396,7 +392,7 @@ void OwnCloudService::slotReplyFinished(QNetworkReply *reply) {
                     // VTODO item) we will remove it
                     if (!wasUpdated) {
                         calItem.remove();
-                    } else if (todoDialog != Q_NULLPTR) {
+                    } else if (todoDialog != nullptr) {
                         // reload the task list items
                         todoDialog->reloadTodoListItems();
                     }
@@ -434,6 +430,9 @@ void OwnCloudService::slotReplyFinished(QNetworkReply *reply) {
             handleImportBookmarksReply(data);
         } else if (url.toString() == serverUrl) {
             qDebug() << "Reply from main server url";
+            if (!settingsDialog) {
+                return;
+            }
 
             if (!data.isEmpty()) {
                 settingsDialog->setOKLabelData(1, tr("ok"),
@@ -474,6 +473,9 @@ void OwnCloudService::checkAppInfo(QNetworkReply *reply) {
                                 .toString();
 
 #ifndef INTEGRATION_TESTS
+    if (!settingsDialog) {
+        return;
+    }
     // reset to "unknown" in case we can't test if versions
     // and trash app are enabled
     settingsDialog->setOKLabelData(6, tr("unknown"),
@@ -854,8 +856,8 @@ void OwnCloudService::setPermissionsOnSharedNote(const Note &note,
     QUrl url(serverUrl % sharePath % QStringLiteral("/") %
              QString::number(note.getShareId()) %
              QStringLiteral("?format=xml"));
-    QString path = NoteFolder::currentRemotePath() +
-                   note.relativeNoteFilePath(QStringLiteral("/"));
+//    QString path = NoteFolder::currentRemotePath() +
+//                   note.relativeNoteFilePath(QStringLiteral("/"));
 
     QUrlQuery params;
     params.addQueryItem(QStringLiteral("permissions"),
@@ -1587,7 +1589,7 @@ void OwnCloudService::loadTodoItems(QString &data) {
 
 #ifndef INTEGRATION_TESTS
     // set the preliminary maximum of the progress bar
-    if (todoDialog != Q_NULLPTR) {
+    if (todoDialog != nullptr) {
         todoDialog->todoItemLoadingProgressBarSetMaximum(responseNodesCount);
     }
 #endif
@@ -1680,7 +1682,7 @@ void OwnCloudService::loadTodoItems(QString &data) {
     }
 
 #ifndef INTEGRATION_TESTS
-    if (todoDialog != Q_NULLPTR) {
+    if (todoDialog != nullptr) {
         // set the real maximum of the progress bar
         todoDialog->todoItemLoadingProgressBarSetMaximum(requestCount);
 
@@ -1702,7 +1704,7 @@ void OwnCloudService::loadTodoItems(QString &data) {
     }
 
 #ifndef INTEGRATION_TESTS
-    if (todoDialog != Q_NULLPTR) {
+    if (todoDialog != nullptr) {
         // reload the existing items
         todoDialog->reloadTodoListItems();
     }
@@ -1734,7 +1736,12 @@ void OwnCloudService::handleUpdateNoteShareReply(const QString &urlPart,
         return;
     }
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+    Q_UNUSED(urlPart)
+    qWarning() << Q_FUNC_INFO << "not implemented for qt6";
+    return;
+#else
+
     //    qDebug() << __func__ << " - 'data': " << data;
 
     QRegularExpression re(QRegularExpression::escape(sharePath) %
@@ -1790,7 +1797,7 @@ void OwnCloudService::handleUpdateNoteShareReply(const QString &urlPart,
 
 #ifndef INTEGRATION_TESTS
     // update the share dialog to show the share url
-    if (shareDialog != Q_NULLPTR) {
+    if (shareDialog != nullptr) {
         shareDialog->updateDialog();
     }
 #endif
@@ -1942,7 +1949,7 @@ void OwnCloudService::updateNoteShareStatus(QXmlQuery &query,
 
 #ifndef INTEGRATION_TESTS
             // update the share dialog to show the share url
-            if (updateShareDialog && (shareDialog != Q_NULLPTR)) {
+            if (updateShareDialog && (shareDialog != nullptr)) {
                 shareDialog->updateDialog();
             }
 #else
@@ -2012,7 +2019,9 @@ void OwnCloudService::loadDirectory(QString &data) {
     }
 
 #ifndef INTEGRATION_TESTS
-    settingsDialog->setNoteFolderRemotePathList(pathList);
+    if (settingsDialog) {
+        settingsDialog->setNoteFolderRemotePathList(pathList);
+    }
 #endif
 }
 
@@ -2074,8 +2083,10 @@ bool OwnCloudService::updateICSDataOfCalendarItem(CalendarItem *calItem) {
     // 5 sec timeout for the request
     timer.start(5000);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
     r.setAttribute(QNetworkRequest::FollowRedirectsAttribute, true);
+#else
+    r.setAttribute(QNetworkRequest::RedirectPolicyAttribute, true);
 #endif
 
     QNetworkReply *reply = manager->get(r);
@@ -2191,9 +2202,11 @@ QByteArray OwnCloudService::downloadNextcloudPreviewImage(const QString &path) {
     QNetworkRequest networkRequest = QNetworkRequest(url);
     addAuthHeader(&networkRequest);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
     networkRequest.setAttribute(QNetworkRequest::FollowRedirectsAttribute,
                                 true);
+#else
+    networkRequest.setAttribute(QNetworkRequest::RedirectPolicyAttribute, true);
 #endif
 
     QByteArray data;
@@ -2313,6 +2326,14 @@ bool OwnCloudService::initiateLoginFlowV2(const QString &serverUrl, QJsonObject
 QString OwnCloudService::fetchNextcloudAccountId(const QString &serverUrl,
                                                       const QString &userName,
                                                       const QString &password) {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+    Q_UNUSED(serverUrl)
+    Q_UNUSED(userName)
+    Q_UNUSED(password)
+    qWarning() << Q_FUNC_INFO << "not implemented for qt6";
+    return {};
+#else
     auto *manager = new QNetworkAccessManager();
     QEventLoop loop;
     QTimer timer;
@@ -2370,4 +2391,5 @@ QString OwnCloudService::fetchNextcloudAccountId(const QString &serverUrl,
     delete (manager);
 
     return {};
+#endif
 }
