@@ -28,6 +28,7 @@ class QTabWidget;
 class QComboBox;
 class QPlainTextEdit;
 class QVBoxLayout;
+class QDockWidget;
 class Tag;
 
 /*  Gui functions that can be useful */
@@ -146,6 +147,7 @@ void reloadNoteTabs(QTabWidget *tabWidget);
 void setTreeWidgetItemToolTipForNote(QTreeWidgetItem *item, const Note &note,
                                      QDateTime *overrideFileLastModified = nullptr);
 bool doWindowsDarkModeCheck();
+bool doLinuxDarkModeCheck();
 
 QIcon folderIcon();
 QIcon noteIcon();
@@ -160,5 +162,6 @@ QIcon tagIcon();
  */
 void handleTreeWidgetItemTagColor(QTreeWidgetItem *item, const Tag &tag);
 void handleTreeWidgetItemTagColor(QTreeWidgetItem *item, int tag);
+bool enableDockWidgetQuestion(QDockWidget *dockWidget);
 }    // namespace Gui
 }    // namespace Utils
