@@ -26,7 +26,7 @@
 
 QOwnNotesMarkdownTextEdit::QOwnNotesMarkdownTextEdit(QWidget *parent)
     : QMarkdownTextEdit(parent, false) {
-    mainWindow = Q_NULLPTR;
+    mainWindow = nullptr;
 
     _highlighter = nullptr;
     if (parent->objectName() != QStringLiteral("LogWidget")) {
@@ -36,10 +36,6 @@ QOwnNotesMarkdownTextEdit::QOwnNotesMarkdownTextEdit(QWidget *parent)
         updateSettings();
     }
 
-    connect(this, &QOwnNotesMarkdownTextEdit::cursorPositionChanged, this,
-            &QOwnNotesMarkdownTextEdit::highlightCurrentLine);
-    highlightCurrentLine();
-
     QSettings settings;
     MarkdownHighlighter::HighlightingOptions options;
 
@@ -81,6 +77,8 @@ QOwnNotesMarkdownTextEdit::QOwnNotesMarkdownTextEdit(QWidget *parent)
         UrlHandler(mainWindow).openUrl(url);
     });
 
+    connect(MainWindow::instance(), &MainWindow::settingsChanged, this, &QOwnNotesMarkdownTextEdit::updateSettings);
+
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, &QOwnNotesMarkdownTextEdit::customContextMenuRequested, this, &QOwnNotesMarkdownTextEdit::onContextMenu);
 }
@@ -776,12 +774,7 @@ void QOwnNotesMarkdownTextEdit::insertBlockQuote()
 }
 
 QMargins QOwnNotesMarkdownTextEdit::viewportMargins() {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
     return QMarkdownTextEdit::viewportMargins();
-#else
-    // This most likely will break line numbers, they aren't really supported in Qt < 5.5
-    return QMargins();
-#endif
 }
 
 void QOwnNotesMarkdownTextEdit::setText(const QString &text) {
@@ -831,7 +824,7 @@ void QOwnNotesMarkdownTextEdit::insertFromMimeData(const QMimeData *source) {
     // if there is text in the clipboard do the normal pasting process
     if (source->hasText()) {
         QMarkdownTextEdit::insertFromMimeData(source);
-    } else if (mainWindow != Q_NULLPTR) {
+    } else if (mainWindow != nullptr) {
         // to more complex pasting if there was no text (and a main window
         // was set)
         mainWindow->handleInsertingFromMimeData(source);
@@ -896,40 +889,17 @@ void QOwnNotesMarkdownTextEdit::updateSettings() {
         }
     }
 
+    const bool hlCurrLine = settings.value(QStringLiteral("Editor/highlightCurrentLine"), true).toBool();
+    setHighlightCurrentLine(hlCurrLine);
+    const auto color = Utils::Schema::schemaSettings->getBackgroundColor(
+    MarkdownHighlighter::HighlighterState::CurrentLineBackgroundColor);
+    setCurrentLineHighlightColor(color);
+
     _centerCursor =
         settings.value(QStringLiteral("Editor/centerCursor")).toBool();
     QMarkdownTextEdit::updateSettings();
 }
 
-/**
- * Highlights the current line if enabled in the settings
- */
-void QOwnNotesMarkdownTextEdit::highlightCurrentLine() {
-    if (!QSettings().value(QStringLiteral("Editor/highlightCurrentLine"), true)
-             .toBool()) {
-        return;
-    }
-
-    QList<QTextEdit::ExtraSelection> extraSelections;
-
-    ensureCursorVisible();
-    QTextEdit::ExtraSelection selection = QTextEdit::ExtraSelection();
-
-    QColor lineColor = Utils::Schema::schemaSettings->getBackgroundColor(
-        MarkdownHighlighter::HighlighterState::CurrentLineBackgroundColor);
-
-    selection.format.setBackground(lineColor);
-    selection.format.setProperty(QTextFormat::FullWidthSelection, true);
-    selection.cursor = textCursor();
-    //        selection.cursor.clearSelection();
-    //        selection.cursor.select(QTextCursor::BlockUnderCursor);
-    extraSelections.append(selection);
-
-    // be aware that extra selections, like for global searching, gets
-    // removed when the current line gets highlighted
-    setExtraSelections(extraSelections);
-}
-
 void QOwnNotesMarkdownTextEdit::onContextMenu(QPoint pos) {
 
     auto *spellCheckMenu = spellCheckContextMenu(pos);
@@ -1116,6 +1086,7 @@ QMenu *QOwnNotesMarkdownTextEdit::spellCheckContextMenu(QPoint pos)
     wordSelectCursor.clearSelection();
     wordSelectCursor.select(QTextCursor::WordUnderCursor);
     QString selectedWord = wordSelectCursor.selectedText();
+    const int selectedWordBlock = wordSelectCursor.blockNumber();
 
     bool isMouseCursorInsideWord = true;
     if ((mousePos < wordSelectCursor.selectionStart() ||
@@ -1175,20 +1146,28 @@ QMenu *QOwnNotesMarkdownTextEdit::spellCheckContextMenu(QPoint pos)
         suggestionsAction->setEnabled(false);
     } else {
         for (const QString& rep : reps) {
-            menu->addAction(rep, this, [rep, this, &cursor](){
-                cursor.insertText(rep);
-                setTextCursor(cursor);
+            menu->addAction(rep, this, [rep, this, cursor]() mutable {
+                if (!cursor.isNull()) {
+                    cursor.insertText(rep);
+                    setTextCursor(cursor);
+                }
             });
         }
     }
 
     menu->addSeparator();
 
-    QAction *ignoreAction = menu->addAction(tr("Ignore"), this, [selectedWord, this](){
+    menu->addAction(tr("Ignore"), this, [selectedWord](){
         QOwnSpellChecker::instance()->ignoreWord(selectedWord);
     });
-    QAction *addToDictAction = menu->addAction(tr("Add to Dictionary"), this, [selectedWord, this](){
+    menu->addAction(tr("Add to Dictionary"), this, [this, selectedWord, selectedWordBlock](){
         QOwnSpellChecker::instance()->addWordToDictionary(selectedWord);
+        if (highlighter() && document()) {
+            const QTextBlock block = document()->findBlockByNumber(selectedWordBlock);
+            if (block.isValid()) {
+                highlighter()->rehighlightBlock(block);
+            }
+        }
     });
 
     menu->setTitle(tr("Spelling"));
@@ -1197,8 +1176,6 @@ QMenu *QOwnNotesMarkdownTextEdit::spellCheckContextMenu(QPoint pos)
 }
 
 bool QOwnNotesMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
-    auto spellchecker = QOwnSpellChecker::instance();
-
     if (event->type() == QEvent::KeyPress) {
         auto *keyEvent = static_cast<QKeyEvent *>(event);
 
@@ -1220,18 +1197,32 @@ bool QOwnNotesMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
 
                 // show notification if user tries to edit a note while
                 // note editing is turned off
-                if ((keyEvent->key() < 128 || keys.contains(keyEvent->key())) &&
-                    keyEvent->modifiers().testFlag(Qt::NoModifier) &&
-                    isReadOnly()) {
+                if (((keyEvent->key() < 128 || keys.contains(keyEvent->key())) && keyEvent->modifiers().testFlag(Qt::NoModifier)) ||
+                    ((keyEvent->key() == Qt::Key_V ) && keyEvent->modifiers().testFlag(Qt::ControlModifier) && isReadOnly())) {
                     if (Utils::Gui::questionNoSkipOverride(
                             this, tr("Note editing disabled"),
                             tr("Note editing is currently disabled, do you "
                                "want to allow it again?"),
                             QStringLiteral("readonly-mode-allow")) ==
                         QMessageBox::Yes) {
-                        if (mainWindow != Q_NULLPTR) {
+                        if (mainWindow != nullptr) {
                             mainWindow->allowNoteEditing();
                         }
+                        // If the answer is overriden to Yes ("Don't ask again" with "Yes"),
+                        // what you type then only enables note editing, but is not typed in
+                        // the editor. We need to re-send the event after enabling editing.
+                        // BUT, we should do that only if the msgbox is overriden to Yes,
+                        // not if manually answered.
+                        // You may see: https://github.com/pbek/QOwnNotes/issues/2421
+                        // This check is partially copied from utils/gui.cpp showMessage()
+                        QSettings settings;
+                        const QString settingsKey = QStringLiteral("MessageBoxOverride/readonly-mode-allow");
+                        auto overrideButton = static_cast<QMessageBox::StandardButton>(
+                            settings.value(settingsKey, QMessageBox::NoButton).toInt());
+                        if (overrideButton == QMessageBox::Yes) {
+                            // overriden to answer yes: re-send the event
+                            return QMarkdownTextEdit::eventFilter(obj, event);
+                        }
                     }
 
                     return true;
@@ -1239,7 +1230,7 @@ bool QOwnNotesMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
             } else {
                 // disable note editing if escape key was pressed
                 if (keyEvent->key() == Qt::Key_Escape &&
-                    mainWindow != Q_NULLPTR) {
+                    mainWindow != nullptr) {
                     mainWindow->disallowNoteEditing();
 
                     return true;
